from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="VehicleImages")


@attr.s(auto_attribs=True)
class VehicleImages:
    """
    Attributes:
        exterior_default_url (Union[Unset, str]):
        interior_default_url (Union[Unset, str]):
    """

    exterior_default_url: Union[Unset, str] = UNSET
    interior_default_url: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        exterior_default_url = self.exterior_default_url
        interior_default_url = self.interior_default_url

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if exterior_default_url is not UNSET:
            field_dict["exteriorDefaultUrl"] = exterior_default_url
        if interior_default_url is not UNSET:
            field_dict["interiorDefaultUrl"] = interior_default_url

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        exterior_default_url = d.pop("exteriorDefaultUrl", UNSET)

        interior_default_url = d.pop("interiorDefaultUrl", UNSET)

        vehicle_images = cls(
            exterior_default_url=exterior_default_url,
            interior_default_url=interior_default_url,
        )

        vehicle_images.additional_properties = d
        return vehicle_images

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
